==> haskell-regex-applicative-0.3.3-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative
version: 0.3.3
id: regex-applicative-0.3.3-I3rRNj55s533YYKiqKRdUu
key: regex-applicative-0.3.3-I3rRNj55s533YYKiqKRdUu
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/regex-applicative
synopsis: Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.
category: Text
abi: abdf3795c52321891f6772c1a3b3a009
exposed: True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue
hidden-modules: Text.Regex.Applicative.Interface
                Text.Regex.Applicative.Types Text.Regex.Applicative.Compile
import-dirs: /usr/lib/ghc-8.6.3/site-local/regex-applicative-0.3.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/regex-applicative-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/regex-applicative-0.3.3
hs-libraries: HSregex-applicative-0.3.3-I3rRNj55s533YYKiqKRdUu
depends:
    base-4.12.0.0 containers-0.6.0.1 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-0.3.3-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative
version: 0.3.3
id: regex-applicative-0.3.3-LhNLVPHToDo5WPzFGWClqT
key: regex-applicative-0.3.3-LhNLVPHToDo5WPzFGWClqT
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/regex-applicative
synopsis: Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.
category: Text
abi: efad41aaadea066ec09378e76c3e034b
exposed: True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue
hidden-modules: Text.Regex.Applicative.Interface
                Text.Regex.Applicative.Types Text.Regex.Applicative.Compile
import-dirs: /usr/lib/ghc-8.6.4/site-local/regex-applicative-0.3.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/regex-applicative-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/regex-applicative-0.3.3
hs-libraries: HSregex-applicative-0.3.3-LhNLVPHToDo5WPzFGWClqT
depends:
    base-4.12.0.0 containers-0.6.0.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
